@@ -133,6 +133,19 @@ build_filename (const TrackDetails *track)
   return string;
 }
 
+static gboolean
+unset_iter_foreach_cb (GtkTreeModel *model, GtkTreePath *path,
+                       GtkTreeIter *iter, gpointer data) 
+{
+  TrackDetails *track;
+
+  gtk_tree_model_get (model, iter, COLUMN_DETAILS, &track, -1);
+  
+  track->iter.stamp = 0;
+  
+  return FALSE;
+}
+
 /**
  * Cleanup the data used, and even enable the Extract button again.
  */
@@ -142,10 +155,18 @@ cleanup (void)
   /* We're not extracting any more */
   extracting = FALSE;
 
+  nautilus_burn_drive_unlock (drive);
+
   /* Remove any state icons from the model */
-  gtk_list_store_set (track_store, &track->iter,
-                 COLUMN_STATE, STATE_IDLE, -1);
-  
+  if (track->iter.stamp) {
+    /* TODO: has to be a better way to do that test */
+    gtk_list_store_set (track_store, &track->iter,
+                        COLUMN_STATE, STATE_IDLE, -1);
+  }
+
+  /* Unset the temporary iterators */
+  gtk_tree_model_foreach (GTK_TREE_MODEL (track_store), unset_iter_foreach_cb, NULL);
+
   /* Free the used data */
   if (paths) {
     g_list_deep_free (paths, NULL);
@@ -154,6 +175,8 @@ cleanup (void)
   g_list_free (pending);
   pending = NULL;
   track = NULL;
+  /* TODO: find out why GTK+ needs this to work (see #364371) */
+  gtk_button_set_label (GTK_BUTTON (extract_button), _("Extract"));
   gtk_button_set_label (GTK_BUTTON (extract_button), SJ_STOCK_EXTRACT);
   
   /* Clear the Status bar */
@@ -265,9 +288,8 @@ pop_and_extract (void)
   if (pending == NULL) {
     g_assert_not_reached ();
   } else {
-    char *file_path, *directory;
+    char *file_path, *directory, *text;
     GError *error = NULL;
-    char *text;
     
     /* Pop the next track to extract */
     track = pending->data;
@@ -569,6 +591,8 @@ on_progress_cancel_clicked (GtkWidget *button, gpointer user_data)
 void
 on_extract_activate (GtkWidget *button, gpointer user_data)
 {
+  char *reason;
+  
   /* first make sure we're not playing, we cannot share the resource */
   stop_playback ();
   
@@ -617,6 +641,8 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
   }
   
   /* Change the label to Stop while extracting*/
+  /* TODO: find out why GTK+ needs this to work (see #364371) */
+  gtk_button_set_label (GTK_BUTTON (extract_button), _("Stop"));
   gtk_button_set_label (GTK_BUTTON (extract_button), GTK_STOCK_STOP);
   
   /* Reset the progress dialog */
@@ -642,6 +668,11 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
   g_object_set (G_OBJECT (artist_renderer), "editable", FALSE, NULL);
   g_signal_handlers_block_by_func (track_listview, on_tracklist_row_activate, NULL);
 
+  if (! nautilus_burn_drive_lock (drive, _("Extracting audio from CD"), &reason)) {
+    g_warning ("Could not lock drive: %s", reason);
+    g_free (reason);
+  }
+
   /* Start the extracting */
   extracting = TRUE;
   pop_and_extract ();
