@@ -244,7 +244,6 @@ void on_eject_activate (GtkMenuItem *item, gpointer user_data)
   /* first make sure we're not playing */
   stop_playback ();
 
-  nautilus_burn_drive_unlock (drive);
   nautilus_burn_drive_eject (drive);
 }
 
@@ -790,12 +789,9 @@ media_removed_cb (NautilusBurnDrive *drive,
 static void
 set_drive_from_device (const char *device)
 {
-  gboolean is_locked;
-  char *reason;
   NautilusBurnDriveMonitor *monitor;
 
   if (drive) {
-    nautilus_burn_drive_unlock (drive);
     nautilus_burn_drive_unref (drive);
     drive = NULL;
   }
@@ -823,12 +819,6 @@ set_drive_from_device (const char *device)
     return;
   }
 
-  is_locked = nautilus_burn_drive_lock (drive, _("Extracting audio from CD"), &reason);
-  if (! is_locked) {
-    g_warning ("Could not lock drive: %s", reason);
-    g_free (reason);
-  }
-
   g_signal_connect (drive, "media-added", G_CALLBACK (media_added_cb), NULL);
   g_signal_connect (drive, "media-removed", G_CALLBACK (media_removed_cb), NULL);
 }
@@ -961,9 +951,9 @@ void profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry,
   
   g_assert (strcmp (entry->key, GCONF_AUDIO_PROFILE) == 0);
   if (!entry->value) return;
-  profile = gm_audio_profile_lookup(gconf_value_get_string (entry->value));
+  profile = gm_audio_profile_lookup (gconf_value_get_string (entry->value));
   if (profile != NULL)
-    g_object_set(extractor, "profile", profile, NULL);
+    g_object_set (extractor, "profile", profile, NULL);
 
   if (profile == NULL || !sj_extractor_supports_profile(profile)) {
     GtkWidget *dialog;
@@ -1332,8 +1322,9 @@ int main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  ctx = g_option_context_new (_("- Extract music from your CDs"));
+  ctx = g_option_context_new (N_("- Extract music from your CDs"));
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
+  g_option_context_set_translation_domain(ctx, GETTEXT_PACKAGE);
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   g_option_context_set_ignore_unknown_options (ctx, TRUE);
 
@@ -1366,11 +1357,6 @@ int main (int argc, char **argv)
   }
 
   metadata = SJ_METADATA (sj_metadata_musicbrainz_new ());
-  error = sj_metadata_get_new_error (metadata);
-  if (error) {
-    error_on_start (error);
-    exit (1);
-  }
   g_signal_connect (metadata, "metadata", G_CALLBACK (metadata_cb), NULL);
 
   gconf_client = gconf_client_get_default ();
